splearn.datasets package
========================

Submodules
----------

splearn.datasets.base module
----------------------------

.. automodule:: splearn.datasets.base
    :members:
    :undoc-members:
    :show-inheritance:

splearn.datasets.data\_sample module
------------------------------------

.. automodule:: splearn.datasets.data_sample
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: splearn.datasets
    :members:
    :undoc-members:
    :show-inheritance:
